@@ -23,10 +23,14 @@ public final class AlertConstants {
     /**
      * the field name of alert show type
      **/
-    public static final String SHOW_TYPE = "show_type";
+    public static final String SHOW_TYPE = "$t('showType')";
 
     public static final String NAME_SHOW_TYPE = "showType";
 
+    public static final String WARNING_TYPE = "warningType";
+
+    public static final String NAME_WARNING_TYPE = "WarningType";
+
     private AlertConstants() {
         throw new UnsupportedOperationException("This is a utility class and cannot be instantiated");
     }
