@@ -31,12 +31,17 @@ import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.impl.client.HttpClientBuilder;
 import org.apache.http.util.EntityUtils;
 import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
+import java.net.MalformedURLException;
+import java.net.URI;
+import java.net.URISyntaxException;
+import java.net.URL;
 import java.util.HashMap;
 import java.util.Map;
 
 public final class HttpSender {
-    private static final Logger log = org.slf4j.LoggerFactory.getLogger(HttpSender.class);
+    private static final Logger logger = LoggerFactory.getLogger(HttpSender.class);
     private static final String URL_SPLICE_CHAR = "?";
     /**
      * request type post
@@ -56,18 +61,24 @@ public final class HttpSender {
 
     public HttpSender(Map<String, String> paramsMap) {
 
-        url = paramsMap.get(HttpAlertConstants.URL);
-        headerParams = paramsMap.get(HttpAlertConstants.HEADER_PARAMS);
-        bodyParams = paramsMap.get(HttpAlertConstants.BODY_PARAMS);
-        contentField = paramsMap.get(HttpAlertConstants.CONTENT_FIELD);
-        requestType = paramsMap.get(HttpAlertConstants.REQUEST_TYPE);
+        url = paramsMap.get(HttpAlertConstants.NAME_URL);
+        headerParams = paramsMap.get(HttpAlertConstants.NAME_HEADER_PARAMS);
+        bodyParams = paramsMap.get(HttpAlertConstants.NAME_BODY_PARAMS);
+        contentField = paramsMap.get(HttpAlertConstants.NAME_CONTENT_FIELD);
+        requestType = paramsMap.get(HttpAlertConstants.NAME_REQUEST_TYPE);
     }
 
     public AlertResult send(String msg) {
 
         AlertResult alertResult = new AlertResult();
 
-        createHttpRequest(msg);
+        try {
+            createHttpRequest(msg);
+        } catch (MalformedURLException e) {
+            throw new RuntimeException(e);
+        } catch (URISyntaxException e) {
+            throw new RuntimeException(e);
+        }
 
         if (httpRequest == null) {
             alertResult.setStatus("false");
@@ -83,7 +94,7 @@ public final class HttpSender {
             alertResult.setStatus("true");
             alertResult.setMessage(resp);
         } catch (Exception e) {
-            log.error("send http alert msg  exception : {}", e.getMessage());
+            logger.error("send http alert msg  exception : {}", e.getMessage());
             alertResult.setStatus("false");
             alertResult.setMessage("send http request  alert fail.");
         }
@@ -91,7 +102,7 @@ public final class HttpSender {
         return alertResult;
     }
 
-    private void createHttpRequest(String msg) {
+    private void createHttpRequest(String msg) throws MalformedURLException, URISyntaxException {
         if (REQUEST_TYPE_POST.equals(requestType)) {
             httpRequest = new HttpPost(url);
             setHeader();
@@ -100,7 +111,10 @@ public final class HttpSender {
         } else if (REQUEST_TYPE_GET.equals(requestType)) {
             //GET request add param in url
             setMsgInUrl(msg);
-            httpRequest = new HttpGet(url);
+            URL unencodeUrl = new URL(url);
+            URI uri = new URI(unencodeUrl.getProtocol(), unencodeUrl.getHost(), unencodeUrl.getPath(), unencodeUrl.getQuery(), null);
+
+            httpRequest = new HttpGet(uri);
             setHeader();
         }
     }
@@ -139,14 +153,14 @@ public final class HttpSender {
      * set body params
      */
     private void setMsgInRequestBody(String msg) {
-        ObjectNode objectNode = JSONUtils.parseObject(bodyParams);
-        //set msg content field
-        objectNode.put(contentField, msg);
         try {
+            ObjectNode objectNode = JSONUtils.parseObject(bodyParams);
+            //set msg content field
+            objectNode.put(contentField, msg);
             StringEntity entity = new StringEntity(JSONUtils.toJsonString(objectNode), DEFAULT_CHARSET);
             ((HttpPost) httpRequest).setEntity(entity);
         } catch (Exception e) {
-            log.error("send http alert msg  exception : {}", e.getMessage());
+            logger.error("send http alert msg  exception : {}", e.getMessage());
         }
     }
 }
