@@ -19,12 +19,13 @@ package org.apache.dolphinscheduler.plugin.alert.script;
 
 import org.apache.dolphinscheduler.alert.api.AlertResult;
 import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import java.io.File;
 import java.util.Map;
 
 public final class ScriptSender {
-    private static final Logger log = org.slf4j.LoggerFactory.getLogger(ScriptSender.class);
+    private static final Logger logger = LoggerFactory.getLogger(ScriptSender.class);
     private static final String ALERT_TITLE_OPTION = " -t ";
     private static final String ALERT_CONTENT_OPTION = " -c ";
     private static final String ALERT_USER_PARAMS_OPTION = " -p ";
@@ -57,13 +58,13 @@ public final class ScriptSender {
         File shellScriptFile = new File(scriptPath);
         //validate existence
         if (!shellScriptFile.exists()) {
-            log.error("shell script not exist : {}", scriptPath);
+            logger.error("shell script not exist : {}", scriptPath);
             alertResult.setMessage("shell script not exist : " + scriptPath);
             return alertResult;
         }
         //validate is file
         if (!shellScriptFile.isFile()) {
-            log.error("shell script is not a file : {}", scriptPath);
+            logger.error("shell script is not a file : {}", scriptPath);
             alertResult.setMessage("shell script is not a file : " + scriptPath);
             return alertResult;
         }
@@ -77,7 +78,7 @@ public final class ScriptSender {
             return alertResult;
         }
         alertResult.setMessage("send script alert msg error,exitCode is " + exitCode);
-        log.info("send script alert msg error,exitCode is {}", exitCode);
+        logger.info("send script alert msg error,exitCode is {}", exitCode);
         return alertResult;
     }
 
