@@ -18,6 +18,7 @@
 package org.apache.dolphinscheduler.api.service;
 
 import org.apache.dolphinscheduler.api.utils.Result;
+import org.apache.dolphinscheduler.common.enums.ProcessExecutionTypeEnum;
 import org.apache.dolphinscheduler.common.enums.ReleaseState;
 import org.apache.dolphinscheduler.dao.entity.TaskDefinitionLog;
 import org.apache.dolphinscheduler.dao.entity.User;
@@ -58,7 +59,8 @@ public interface ProcessDefinitionService {
                                                 int timeout,
                                                 String tenantCode,
                                                 String taskRelationJson,
-                                                String taskDefinitionJson);
+                                                String taskDefinitionJson,
+                                                ProcessExecutionTypeEnum executionType);
 
     /**
      * query process definition list
@@ -176,7 +178,8 @@ public interface ProcessDefinitionService {
                                                 int timeout,
                                                 String tenantCode,
                                                 String taskRelationJson,
-                                                String taskDefinitionJson);
+                                                String taskDefinitionJson,
+                                                ProcessExecutionTypeEnum executionType);
 
     /**
      * verify process definition name unique
@@ -241,6 +244,18 @@ public interface ProcessDefinitionService {
                                                 long projectCode,
                                                 MultipartFile file);
 
+    /**
+     * import sql process definition
+     *
+     * @param loginUser login user
+     * @param projectCode project code
+     * @param file sql file, zip
+     * @return import process
+     */
+    Map<String, Object> importSqlProcessDefinition(User loginUser,
+                                                   long projectCode,
+                                                   MultipartFile file);
+
     /**
      * check the process task relation json
      *
@@ -281,6 +296,23 @@ public interface ProcessDefinitionService {
      */
     Map<String, Object> queryAllProcessDefinitionByProjectCode(User loginUser, long projectCode);
 
+    /**
+     * query process definition list by project code
+     *
+     * @param projectCode project code
+     * @return process definitions in the project
+     */
+    Map<String, Object> queryProcessDefinitionListByProjectCode(long projectCode);
+
+    /**
+     * query process definition list by project code
+     *
+     * @param projectCode project code
+     * @param processDefinitionCode process definition code
+     * @return process definitions in the project
+     */
+    Map<String, Object> queryTaskDefinitionListByProcessDefinitionCode(long projectCode, Long processDefinitionCode);
+
     /**
      * Encapsulates the TreeView structure
      *
@@ -355,7 +387,8 @@ public interface ProcessDefinitionService {
                                                      String globalParams,
                                                      int timeout,
                                                      String tenantCode,
-                                                     String scheduleJson);
+                                                     String scheduleJson,
+                                                     ProcessExecutionTypeEnum executionType);
 
     /**
      * update process definition basic info
@@ -369,6 +402,7 @@ public interface ProcessDefinitionService {
      * @param timeout timeout
      * @param tenantCode tenantCode
      * @param scheduleJson scheduleJson
+     * @param executionType executionType
      * @return update result code
      */
     Map<String, Object> updateProcessDefinitionBasicInfo(User loginUser,
@@ -379,7 +413,8 @@ public interface ProcessDefinitionService {
                                                          String globalParams,
                                                          int timeout,
                                                          String tenantCode,
-                                                         String scheduleJson);
+                                                         String scheduleJson,
+                                                         ProcessExecutionTypeEnum executionType);
 
     /**
      * release process definition and schedule
