@@ -17,37 +17,81 @@
 
 package org.apache.dolphinscheduler.api.service.impl;
 
-import com.fasterxml.jackson.core.type.TypeReference;
-import org.apache.commons.collections.CollectionUtils;
-import org.apache.commons.collections.MapUtils;
-import org.apache.commons.lang.StringUtils;
+import static org.apache.dolphinscheduler.common.Constants.CMDPARAM_COMPLEMENT_DATA_END_DATE;
+import static org.apache.dolphinscheduler.common.Constants.CMDPARAM_COMPLEMENT_DATA_START_DATE;
+import static org.apache.dolphinscheduler.common.Constants.CMD_PARAM_RECOVER_PROCESS_ID_STRING;
+import static org.apache.dolphinscheduler.common.Constants.CMD_PARAM_START_NODES;
+import static org.apache.dolphinscheduler.common.Constants.CMD_PARAM_START_PARAMS;
+import static org.apache.dolphinscheduler.common.Constants.MAX_TASK_TIMEOUT;
+
 import org.apache.dolphinscheduler.api.enums.ExecuteType;
 import org.apache.dolphinscheduler.api.enums.Status;
-import org.apache.dolphinscheduler.api.exceptions.ServiceException;
 import org.apache.dolphinscheduler.api.service.ExecutorService;
 import org.apache.dolphinscheduler.api.service.MonitorService;
 import org.apache.dolphinscheduler.api.service.ProjectService;
 import org.apache.dolphinscheduler.common.Constants;
-import org.apache.dolphinscheduler.common.enums.*;
+import org.apache.dolphinscheduler.common.enums.CommandType;
+import org.apache.dolphinscheduler.common.enums.ComplementDependentMode;
+import org.apache.dolphinscheduler.common.enums.CycleEnum;
+import org.apache.dolphinscheduler.common.enums.FailureStrategy;
+import org.apache.dolphinscheduler.common.enums.Flag;
+import org.apache.dolphinscheduler.common.enums.Priority;
+import org.apache.dolphinscheduler.common.enums.ReleaseState;
+import org.apache.dolphinscheduler.common.enums.RunMode;
+import org.apache.dolphinscheduler.common.enums.TaskDependType;
+import org.apache.dolphinscheduler.common.enums.TaskGroupQueueStatus;
+import org.apache.dolphinscheduler.common.enums.WarningType;
 import org.apache.dolphinscheduler.common.model.Server;
 import org.apache.dolphinscheduler.common.utils.DateUtils;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
-import org.apache.dolphinscheduler.dao.entity.*;
+import org.apache.dolphinscheduler.dao.entity.Command;
+import org.apache.dolphinscheduler.dao.entity.DependentProcessDefinition;
+import org.apache.dolphinscheduler.dao.entity.ProcessDefinition;
+import org.apache.dolphinscheduler.dao.entity.ProcessInstance;
+import org.apache.dolphinscheduler.dao.entity.ProcessTaskRelation;
+import org.apache.dolphinscheduler.dao.entity.Project;
+import org.apache.dolphinscheduler.dao.entity.Schedule;
+import org.apache.dolphinscheduler.dao.entity.TaskDefinition;
+import org.apache.dolphinscheduler.dao.entity.TaskGroupQueue;
+import org.apache.dolphinscheduler.dao.entity.Tenant;
+import org.apache.dolphinscheduler.dao.entity.User;
 import org.apache.dolphinscheduler.dao.mapper.ProcessDefinitionMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProcessInstanceMapper;
+import org.apache.dolphinscheduler.dao.mapper.ProcessTaskRelationMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProjectMapper;
+import org.apache.dolphinscheduler.dao.mapper.TaskDefinitionMapper;
+import org.apache.dolphinscheduler.dao.mapper.TaskGroupQueueMapper;
+import org.apache.dolphinscheduler.plugin.task.api.TaskConstants;
+import org.apache.dolphinscheduler.plugin.task.api.enums.ExecutionStatus;
 import org.apache.dolphinscheduler.remote.command.StateEventChangeCommand;
+import org.apache.dolphinscheduler.remote.command.WorkflowExecutingDataRequestCommand;
+import org.apache.dolphinscheduler.remote.command.WorkflowExecutingDataResponseCommand;
+import org.apache.dolphinscheduler.remote.dto.WorkflowExecuteDto;
 import org.apache.dolphinscheduler.remote.processor.StateEventCallbackService;
+import org.apache.dolphinscheduler.remote.utils.Host;
 import org.apache.dolphinscheduler.service.process.ProcessService;
 import org.apache.dolphinscheduler.service.quartz.cron.CronUtils;
+
+import org.apache.commons.beanutils.BeanUtils;
+import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.collections.MapUtils;
+import org.apache.commons.lang.StringUtils;
+
+import java.util.ArrayList;
+import java.util.Date;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+import java.util.stream.Collectors;
+
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Service;
 
-import java.util.*;
-
-import static org.apache.dolphinscheduler.common.Constants.*;
+import com.fasterxml.jackson.core.type.TypeReference;
 
 /**
  * executor service impl
@@ -69,16 +113,23 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
     @Autowired
     private MonitorService monitorService;
 
-
     @Autowired
     private ProcessInstanceMapper processInstanceMapper;
 
-
     @Autowired
     private ProcessService processService;
 
     @Autowired
-    StateEventCallbackService stateEventCallbackService;
+    private StateEventCallbackService stateEventCallbackService;
+
+    @Autowired
+    private TaskDefinitionMapper taskDefinitionMapper;
+
+    @Autowired
+    private ProcessTaskRelationMapper processTaskRelationMapper;
+
+    @Autowired
+    private TaskGroupQueueMapper taskGroupQueueMapper;
 
     /**
      * execute process instance
@@ -110,7 +161,8 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
                                                    RunMode runMode,
                                                    Priority processInstancePriority, String workerGroup, Long environmentCode,Integer timeout,
                                                    Map<String, String> startParams, Integer expectedParallelismNumber,
-                                                   int dryRun) {
+                                                   int dryRun,
+                                                   ComplementDependentMode complementDependentMode) {
         Project project = projectMapper.queryByCode(projectCode);
         //check user access for project
         Map<String, Object> result = projectService.checkProjectAndAuth(loginUser, project, projectCode);
@@ -125,7 +177,7 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
 
         // check process define release state
         ProcessDefinition processDefinition = processDefinitionMapper.queryByCode(processDefinitionCode);
-        result = checkProcessDefinitionValid(projectCode, processDefinition, processDefinitionCode);
+        result = checkProcessDefinitionValid(projectCode, processDefinition, processDefinitionCode, processDefinition.getVersion());
         if (result.get(Constants.STATUS) != Status.SUCCESS) {
             return result;
         }
@@ -145,23 +197,18 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
         /**
          * create command
          */
-        try {
-            int create = this.createCommand(commandType, processDefinition.getCode(),
-                    taskDependType, failureStrategy, startNodeList, cronTime, warningType, loginUser.getId(),
-                    warningGroupId, runMode, processInstancePriority, workerGroup, environmentCode, startParams, expectedParallelismNumber, dryRun);
+        int create = this.createCommand(commandType, processDefinition.getCode(),
+                taskDependType, failureStrategy, startNodeList, cronTime, warningType, loginUser.getId(),
+                warningGroupId, runMode, processInstancePriority, workerGroup, environmentCode, startParams,
+                expectedParallelismNumber, dryRun, complementDependentMode);
 
-            if (create > 0) {
-                processDefinition.setWarningGroupId(warningGroupId);
-                processDefinitionMapper.updateById(processDefinition);
-                putMsg(result, Status.SUCCESS);
-            } else {
-                putMsg(result, Status.START_PROCESS_INSTANCE_ERROR);
-            }
-        } catch (ServiceException e) {
-            Optional<Status> status = Status.findStatusBy(e.getCode());
-            putMsg(result, status.orElse(Status.START_PROCESS_INSTANCE_ERROR));
+        if (create > 0) {
+            processDefinition.setWarningGroupId(warningGroupId);
+            processDefinitionMapper.updateById(processDefinition);
+            putMsg(result, Status.SUCCESS);
+        } else {
+            putMsg(result, Status.START_PROCESS_INSTANCE_ERROR);
         }
-
         return result;
     }
 
@@ -189,23 +236,57 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
      * @param projectCode project code
      * @param processDefinition process definition
      * @param processDefineCode process definition code
+     * @param version process instance verison
      * @return check result code
      */
     @Override
-    public Map<String, Object> checkProcessDefinitionValid(long projectCode, ProcessDefinition processDefinition, long processDefineCode) {
+    public Map<String, Object> checkProcessDefinitionValid(long projectCode, ProcessDefinition processDefinition, long processDefineCode, Integer version) {
         Map<String, Object> result = new HashMap<>();
         if (processDefinition == null || projectCode != processDefinition.getProjectCode()) {
             // check process definition exists
-            putMsg(result, Status.PROCESS_DEFINE_NOT_EXIST, processDefineCode);
+            putMsg(result, Status.PROCESS_DEFINE_NOT_EXIST, String.valueOf(processDefineCode));
         } else if (processDefinition.getReleaseState() != ReleaseState.ONLINE) {
             // check process definition online
-            putMsg(result, Status.PROCESS_DEFINE_NOT_RELEASE, processDefineCode);
+            putMsg(result, Status.PROCESS_DEFINE_NOT_RELEASE, String.valueOf(processDefineCode), version);
+        } else if (!checkSubProcessDefinitionValid(processDefinition)) {
+            // check sub process definition online
+            putMsg(result, Status.SUB_PROCESS_DEFINE_NOT_RELEASE);
         } else {
             result.put(Constants.STATUS, Status.SUCCESS);
         }
         return result;
     }
 
+    /**
+     * check if the current process has subprocesses and all subprocesses are valid
+     * @param processDefinition
+     * @return check result
+     */
+    @Override
+    public boolean checkSubProcessDefinitionValid(ProcessDefinition processDefinition) {
+        // query all subprocesses under the current process
+        List<ProcessTaskRelation> processTaskRelations = processTaskRelationMapper.queryDownstreamByProcessDefinitionCode(processDefinition.getCode());
+        if (processTaskRelations.isEmpty()) {
+            return true;
+        }
+        Set<Long> relationCodes = processTaskRelations.stream().map(ProcessTaskRelation::getPostTaskCode).collect(Collectors.toSet());
+        List<TaskDefinition> taskDefinitions = taskDefinitionMapper.queryByCodeList(relationCodes);
+
+        // find out the process definition code
+        Set<Long> processDefinitionCodeSet = new HashSet<>();
+        taskDefinitions.stream()
+                .filter(task -> TaskConstants.TASK_TYPE_SUB_PROCESS.equalsIgnoreCase(task.getTaskType()))
+                .forEach(taskDefinition -> processDefinitionCodeSet.add(Long.valueOf(JSONUtils.getNodeString(taskDefinition.getTaskParams(), Constants.CMD_PARAM_SUB_PROCESS_DEFINE_CODE))));
+        if (processDefinitionCodeSet.isEmpty()) {
+            return true;
+        }
+
+        // check sub releaseState
+        List<ProcessDefinition> processDefinitions = processDefinitionMapper.queryByCodes(processDefinitionCodeSet);
+        return processDefinitions.stream().filter(definition -> definition.getReleaseState().equals(ReleaseState.OFFLINE)).collect(Collectors.toSet()).isEmpty();
+    }
+
+
     /**
      * do action to process instance：pause, stop, repeat, recover from pause, recover from stop
      *
@@ -238,7 +319,7 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
         ProcessDefinition processDefinition = processService.findProcessDefinition(processInstance.getProcessDefinitionCode(),
                 processInstance.getProcessDefinitionVersion());
         if (executeType != ExecuteType.STOP && executeType != ExecuteType.PAUSE) {
-            result = checkProcessDefinitionValid(projectCode, processDefinition, processInstance.getProcessDefinitionCode());
+            result = checkProcessDefinitionValid(projectCode, processDefinition, processInstance.getProcessDefinitionCode(), processInstance.getProcessDefinitionVersion());
             if (result.get(Constants.STATUS) != Status.SUCCESS) {
                 return result;
             }
@@ -297,6 +378,24 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
         return result;
     }
 
+    @Override
+    public Map<String, Object> forceStartTaskInstance(User loginUser, int queueId) {
+        Map<String, Object> result = new HashMap<>();
+        TaskGroupQueue taskGroupQueue = taskGroupQueueMapper.selectById(queueId);
+        // check process instance exist
+        ProcessInstance processInstance = processInstanceMapper.selectById(taskGroupQueue.getProcessId());
+        if (processInstance == null) {
+            putMsg(result, Status.PROCESS_INSTANCE_NOT_EXIST, taskGroupQueue.getProcessId());
+            return result;
+        }
+
+        // check master exists
+        if (!checkMasterExists(result)) {
+            return result;
+        }
+        return forceStart(processInstance, taskGroupQueue);
+    }
+
     /**
      * check tenant suitable
      *
@@ -339,7 +438,7 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
                 }
                 break;
             case RECOVER_SUSPENDED_PROCESS:
-                if (executionStatus.typeIsCancel()) {
+                if (executionStatus.typeIsPause() || executionStatus.typeIsCancel()) {
                     checkResult = true;
                 }
                 break;
@@ -372,13 +471,12 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
 
         // determine whether the process is normal
         if (update > 0) {
-            String host = processInstance.getHost();
-            String address = host.split(":")[0];
-            int port = Integer.parseInt(host.split(":")[1]);
+            // directly send the process instance state change event to target master, not guarantee the event send success
             StateEventChangeCommand stateEventChangeCommand = new StateEventChangeCommand(
                     processInstance.getId(), 0, processInstance.getState(), processInstance.getId(), 0
             );
-            stateEventCallbackService.sendResult(address, port, stateEventChangeCommand.convert2Command());
+            Host host = new Host(processInstance.getHost());
+            stateEventCallbackService.sendResult(host, stateEventChangeCommand.convert2Command());
             putMsg(result, Status.SUCCESS);
         } else {
             putMsg(result, Status.EXECUTE_PROCESS_INSTANCE_ERROR);
@@ -386,6 +484,27 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
         return result;
     }
 
+    /**
+     * prepare to update process instance command type and status
+     *
+     * @param processInstance process instance
+     * @return update result
+     */
+    private Map<String, Object> forceStart(ProcessInstance processInstance, TaskGroupQueue taskGroupQueue) {
+        Map<String, Object> result = new HashMap<>();
+        if (taskGroupQueue.getStatus() != TaskGroupQueueStatus.WAIT_QUEUE) {
+            putMsg(result, Status.TASK_GROUP_QUEUE_ALREADY_START);
+            return result;
+        }
+
+        taskGroupQueue.setForceStart(Flag.YES.getCode());
+        processService.updateTaskGroupQueue(taskGroupQueue);
+        processService.sendStartTask2Master(processInstance, taskGroupQueue.getTaskId()
+                ,org.apache.dolphinscheduler.remote.command.CommandType.TASK_FORCE_STATE_EVENT_REQUEST);
+        putMsg(result, Status.SUCCESS);
+        return result;
+    }
+
     /**
      * insert command, used in the implementation of the page, re run, recovery (pause / failure) execution
      *
@@ -415,7 +534,7 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
         command.setProcessInstanceId(instanceId);
 
         if (!processService.verifyIsNeedCreateCommand(command)) {
-            putMsg(result, Status.PROCESS_INSTANCE_EXECUTING_COMMAND, processDefinitionCode);
+            putMsg(result, Status.PROCESS_INSTANCE_EXECUTING_COMMAND, String.valueOf(processDefinitionCode));
             return result;
         }
 
@@ -493,7 +612,7 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
                               String startNodeList, String schedule, WarningType warningType,
                               int executorId, int warningGroupId,
                               RunMode runMode, Priority processInstancePriority, String workerGroup, Long environmentCode,
-                              Map<String, String> startParams, Integer expectedParallelismNumber, int dryRun) {
+                              Map<String, String> startParams, Integer expectedParallelismNumber, int dryRun, ComplementDependentMode complementDependentMode) {
 
         /**
          * instantiate command schedule instance
@@ -556,7 +675,7 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
             if (start == null || end == null) {
                 return 0;
             }
-            return createComplementCommandList(start, end, runMode, command, expectedParallelismNumber);
+            return createComplementCommandList(start, end, runMode, command, expectedParallelismNumber, complementDependentMode);
         } else {
             command.setCommandParam(JSONUtils.toJsonString(cmdParam));
             return processService.createCommand(command);
@@ -565,25 +684,20 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
 
     /**
      * create complement command
-     * close left open right
+     * close left and close right
      *
      * @param start
      * @param end
      * @param runMode
      * @return
      */
-    private int createComplementCommandList(Date start, Date end, RunMode runMode, Command command, Integer expectedParallelismNumber) {
+    protected int createComplementCommandList(Date start, Date end, RunMode runMode, Command command,
+                                            Integer expectedParallelismNumber, ComplementDependentMode complementDependentMode) {
         int createCount = 0;
+        int dependentProcessDefinitionCreateCount = 0;
+
         runMode = (runMode == null) ? RunMode.RUN_MODE_SERIAL : runMode;
         Map<String, String> cmdParam = JSONUtils.toMap(command.getCommandParam());
-        List<Schedule> schedules = processService.queryReleaseSchedulerListByProcessDefinitionCode(command.getProcessDefinitionCode());
-        LinkedList<Date> listDate = new LinkedList<>(CronUtils.getSelfFireDateList(start, end, schedules));
-        final int listDateSize = listDate.size();
-        if (listDateSize == 0) {
-            logger.warn("can't create complement command, because the fire date cannot be created, scope: {} ~ {}",
-                    DateUtils.dateToString(start), DateUtils.dateToString(end));
-            throw new ServiceException(Status.COMPLEMENT_PROCESS_INSTANCE_DATE_RANGE_ERROR);
-        }
         switch (runMode) {
             case RUN_MODE_SERIAL: {
                 if (start.after(end)) {
@@ -594,6 +708,17 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
                 cmdParam.put(CMDPARAM_COMPLEMENT_DATA_END_DATE, DateUtils.dateToString(end));
                 command.setCommandParam(JSONUtils.toJsonString(cmdParam));
                 createCount = processService.createCommand(command);
+
+                // dependent process definition
+                List<Schedule> schedules = processService.queryReleaseSchedulerListByProcessDefinitionCode(command.getProcessDefinitionCode());
+
+                if (schedules.isEmpty() || complementDependentMode == ComplementDependentMode.OFF_MODE) {
+                    logger.info("process code: {} complement dependent in off mode or schedule's size is 0, skip "
+                            + "dependent complement data", command.getProcessDefinitionCode());
+                } else {
+                    dependentProcessDefinitionCreateCount += createComplementDependentCommand(schedules, command);
+                }
+
                 break;
             }
             case RUN_MODE_PARALLEL: {
@@ -602,6 +727,10 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
                     break;
                 }
 
+                List<Date> listDate = new ArrayList<>();
+                List<Schedule> schedules = processService.queryReleaseSchedulerListByProcessDefinitionCode(command.getProcessDefinitionCode());
+                listDate.addAll(CronUtils.getSelfFireDateList(start, end, schedules));
+                int listDateSize = listDate.size();
                 createCount = listDate.size();
                 if (!CollectionUtils.isEmpty(listDate)) {
                     if (expectedParallelismNumber != null && expectedParallelismNumber != 0) {
@@ -634,6 +763,13 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
                         cmdParam.put(CMDPARAM_COMPLEMENT_DATA_END_DATE, DateUtils.dateToString(listDate.get(endDateIndex)));
                         command.setCommandParam(JSONUtils.toJsonString(cmdParam));
                         processService.createCommand(command);
+
+                        if (schedules.isEmpty() || complementDependentMode == ComplementDependentMode.OFF_MODE) {
+                            logger.info("process code: {} complement dependent in off mode or schedule's size is 0, skip "
+                                    + "dependent complement data", command.getProcessDefinitionCode());
+                        } else {
+                            dependentProcessDefinitionCreateCount += createComplementDependentCommand(schedules, command);
+                        }
                     }
                 }
                 break;
@@ -641,7 +777,103 @@ public class ExecutorServiceImpl extends BaseServiceImpl implements ExecutorServ
             default:
                 break;
         }
-        logger.info("create complement command count: {}", createCount);
+        logger.info("create complement command count: {}, create dependent complement command count: {}", createCount
+                , dependentProcessDefinitionCreateCount);
         return createCount;
     }
+
+    /**
+     * create complement dependent command
+     */
+    protected int createComplementDependentCommand(List<Schedule> schedules, Command command) {
+        int dependentProcessDefinitionCreateCount = 0;
+        Command dependentCommand;
+
+        try {
+            dependentCommand = (Command) BeanUtils.cloneBean(command);
+        } catch (Exception e) {
+            logger.error("copy dependent command error: ", e);
+            return dependentProcessDefinitionCreateCount;
+        }
+
+        List<DependentProcessDefinition> dependentProcessDefinitionList =
+                getComplementDependentDefinitionList(dependentCommand.getProcessDefinitionCode(),
+                        CronUtils.getMaxCycle(schedules.get(0).getCrontab()),
+                        dependentCommand.getWorkerGroup());
+
+        dependentCommand.setTaskDependType(TaskDependType.TASK_POST);
+        for (DependentProcessDefinition dependentProcessDefinition : dependentProcessDefinitionList) {
+            dependentCommand.setProcessDefinitionCode(dependentProcessDefinition.getProcessDefinitionCode());
+            dependentCommand.setWorkerGroup(dependentProcessDefinition.getWorkerGroup());
+            Map<String, String> cmdParam = JSONUtils.toMap(dependentCommand.getCommandParam());
+            cmdParam.put(CMD_PARAM_START_NODES, String.valueOf(dependentProcessDefinition.getTaskDefinitionCode()));
+            dependentCommand.setCommandParam(JSONUtils.toJsonString(cmdParam));
+            dependentProcessDefinitionCreateCount += processService.createCommand(dependentCommand);
+        }
+
+        return dependentProcessDefinitionCreateCount;
+    }
+
+    /**
+     * get complement dependent process definition list
+     */
+    private List<DependentProcessDefinition> getComplementDependentDefinitionList(long processDefinitionCode,
+                                                                               CycleEnum processDefinitionCycle,
+                                                                               String workerGroup) {
+        List<DependentProcessDefinition> dependentProcessDefinitionList =
+                processService.queryDependentProcessDefinitionByProcessDefinitionCode(processDefinitionCode);
+
+        return checkDependentProcessDefinitionValid(dependentProcessDefinitionList,processDefinitionCycle,workerGroup);
+    }
+
+    /**
+     *  Check whether the dependency cycle of the dependent node is consistent with the schedule cycle of
+     *  the dependent process definition and if there is no worker group in the schedule, use the complement selection's
+     *  worker group
+     */
+    private List<DependentProcessDefinition> checkDependentProcessDefinitionValid(List<DependentProcessDefinition> dependentProcessDefinitionList,
+                                                                             CycleEnum processDefinitionCycle,
+                                                                             String workerGroup) {
+        List<DependentProcessDefinition> validDependentProcessDefinitionList = new ArrayList<>();
+
+        List<Long> processDefinitionCodeList = dependentProcessDefinitionList.stream()
+                .map(DependentProcessDefinition::getProcessDefinitionCode)
+                .collect(Collectors.toList());
+
+        Map<Long, String> processDefinitionWorkerGroupMap = processService.queryWorkerGroupByProcessDefinitionCodes(processDefinitionCodeList);
+
+        for (DependentProcessDefinition dependentProcessDefinition : dependentProcessDefinitionList) {
+            if (dependentProcessDefinition.getDependentCycle() == processDefinitionCycle) {
+                if (processDefinitionWorkerGroupMap.get(dependentProcessDefinition.getProcessDefinitionCode()) == null) {
+                    dependentProcessDefinition.setWorkerGroup(workerGroup);
+                }
+
+                validDependentProcessDefinitionList.add(dependentProcessDefinition);
+            }
+        }
+
+        return validDependentProcessDefinitionList;
+    }
+
+    /**
+     * query executing data of processInstance by master
+     * @param processInstanceId
+     * @return
+     */
+    @Override
+    public WorkflowExecuteDto queryExecutingWorkflowByProcessInstanceId(Integer processInstanceId) {
+        ProcessInstance processInstance = processService.findProcessInstanceDetailById(processInstanceId);
+        if (processInstance == null) {
+            return null;
+        }
+        Host host = new Host(processInstance.getHost());
+        WorkflowExecutingDataRequestCommand requestCommand = new WorkflowExecutingDataRequestCommand();
+        requestCommand.setProcessInstanceId(processInstanceId);
+        org.apache.dolphinscheduler.remote.command.Command command = stateEventCallbackService.sendSync(host, requestCommand.convert2Command());
+        if (command == null) {
+            return null;
+        }
+        WorkflowExecutingDataResponseCommand responseCommand = JSONUtils.parseObject(command.getBody(), WorkflowExecutingDataResponseCommand.class);
+        return responseCommand.getWorkflowExecuteDto();
+    }
 }
