@@ -18,6 +18,7 @@
 package org.apache.dolphinscheduler.common.utils;
 
 import org.apache.dolphinscheduler.common.Constants;
+import org.apache.dolphinscheduler.common.thread.ThreadLocalContext;
 
 import org.apache.commons.lang.StringUtils;
 
@@ -44,6 +45,7 @@ public final class DateUtils {
     static final long C6 = C5 * 24L;
 
     private static final Logger logger = LoggerFactory.getLogger(DateUtils.class);
+    private static final DateTimeFormatter YYYY_MM_DD_HH_MM_SS = DateTimeFormatter.ofPattern(Constants.YYYY_MM_DD_HH_MM_SS);
 
     private DateUtils() {
         throw new UnsupportedOperationException("Construct DateUtils");
@@ -56,7 +58,20 @@ public final class DateUtils {
      * @return local datetime
      */
     private static LocalDateTime date2LocalDateTime(Date date) {
-        return LocalDateTime.ofInstant(date.toInstant(), ZoneId.systemDefault());
+        String timezone = ThreadLocalContext.getTimezoneThreadLocal().get();
+        ZoneId zoneId = StringUtils.isNotEmpty(timezone) ? ZoneId.of(timezone) : ZoneId.systemDefault();
+        return date2LocalDateTime(date, zoneId);
+    }
+
+    /**
+     * date to local datetime
+     *
+     * @param date date
+     * @param zoneId zoneId
+     * @return local datetime
+     */
+    private static LocalDateTime date2LocalDateTime(Date date, ZoneId zoneId) {
+        return LocalDateTime.ofInstant(date.toInstant(), zoneId);
     }
 
     /**
@@ -66,17 +81,20 @@ public final class DateUtils {
      * @return date
      */
     private static Date localDateTime2Date(LocalDateTime localDateTime) {
-        Instant instant = localDateTime.atZone(ZoneId.systemDefault()).toInstant();
-        return Date.from(instant);
+        String timezone = ThreadLocalContext.getTimezoneThreadLocal().get();
+        ZoneId zoneId = StringUtils.isNotEmpty(timezone) ? ZoneId.of(timezone) : ZoneId.systemDefault();
+        return localDateTime2Date(localDateTime, zoneId);
     }
 
     /**
-     * get current date str
+     * local datetime to date
      *
-     * @return date string
+     * @param localDateTime local datetime
+     * @return date
      */
-    public static String getCurrentTime() {
-        return getCurrentTime(Constants.YYYY_MM_DD_HH_MM_SS);
+    private static Date localDateTime2Date(LocalDateTime localDateTime, ZoneId zoneId) {
+        Instant instant = localDateTime.atZone(zoneId).toInstant();
+        return Date.from(instant);
     }
 
     /**
@@ -92,23 +110,32 @@ public final class DateUtils {
     /**
      * get the formatted date string
      *
-     * @param date date
+     * @param date   date
      * @param format e.g. yyyy-MM-dd HH:mm:ss
      * @return date string
      */
-    public static String format(Date date, String format) {
-        return format(date2LocalDateTime(date), format);
+    public static String format(Date date, String format, String timezone) {
+        return format(date, DateTimeFormatter.ofPattern(format), timezone);
+    }
+
+    public static String format(Date date, DateTimeFormatter dateTimeFormatter, String timezone) {
+        LocalDateTime localDateTime = StringUtils.isEmpty(timezone) ? date2LocalDateTime(date) : date2LocalDateTime(date, ZoneId.of(timezone));
+        return format(localDateTime, dateTimeFormatter);
     }
 
     /**
      * get the formatted date string
      *
      * @param localDateTime local data time
-     * @param format yyyy-MM-dd HH:mm:ss
+     * @param format        yyyy-MM-dd HH:mm:ss
      * @return date string
      */
     public static String format(LocalDateTime localDateTime, String format) {
-        return localDateTime.format(DateTimeFormatter.ofPattern(format));
+        return format(localDateTime, DateTimeFormatter.ofPattern(format));
+    }
+
+    public static String format(LocalDateTime localDateTime, DateTimeFormatter dateTimeFormatter) {
+        return localDateTime.format(dateTimeFormatter);
     }
 
     /**
@@ -118,20 +145,71 @@ public final class DateUtils {
      * @return date string
      */
     public static String dateToString(Date date) {
-        return format(date, Constants.YYYY_MM_DD_HH_MM_SS);
+        return format(date, YYYY_MM_DD_HH_MM_SS, null);
+    }
+
+    /**
+     * convert time to yyyy-MM-dd HH:mm:ss format
+     *
+     * @param date date
+     * @param timezone timezone
+     * @return date string
+     */
+    public static String dateToString(Date date, String timezone) {
+        return format(date, YYYY_MM_DD_HH_MM_SS, timezone);
+    }
+
+    /**
+     * convert zone date time to yyyy-MM-dd HH:mm:ss format
+     *
+     * @param zonedDateTime zone date time
+     * @return zone date time string
+     */
+    public static String dateToString(ZonedDateTime zonedDateTime) {
+        return YYYY_MM_DD_HH_MM_SS.format(zonedDateTime);
+    }
+
+    /**
+     * convert zone date time to yyyy-MM-dd HH:mm:ss format
+     *
+     * @param zonedDateTime zone date time
+     * @param timezone      time zone
+     * @return zone date time string
+     */
+    public static String dateToString(ZonedDateTime zonedDateTime, String timezone) {
+        return dateToString(zonedDateTime, ZoneId.of(timezone));
+    }
+
+    /**
+     * convert zone date time to yyyy-MM-dd HH:mm:ss format
+     *
+     * @param zonedDateTime zone date time
+     * @param zoneId        zone id
+     * @return zone date time string
+     */
+    public static String dateToString(ZonedDateTime zonedDateTime, ZoneId zoneId) {
+        return DateTimeFormatter.ofPattern(Constants.YYYY_MM_DD_HH_MM_SS).withZone(zoneId).format(zonedDateTime);
     }
 
     /**
      * convert string to date and time
      *
-     * @param date date
+     * @param date   date
      * @param format format
+     * @param timezone timezone, if null, use system default timezone
      * @return date
      */
-    public static Date parse(String date, String format) {
+    public static Date parse(String date, String format, String timezone) {
+        return parse(date, DateTimeFormatter.ofPattern(format), timezone);
+    }
+
+    public static Date parse(String date, DateTimeFormatter dateTimeFormatter, String timezone) {
         try {
-            LocalDateTime ldt = LocalDateTime.parse(date, DateTimeFormatter.ofPattern(format));
-            return localDateTime2Date(ldt);
+            LocalDateTime ldt = LocalDateTime.parse(date, dateTimeFormatter);
+            if (StringUtils.isEmpty(timezone)) {
+                return localDateTime2Date(ldt);
+            }
+            return localDateTime2Date(ldt, ZoneId.of(timezone));
         } catch (Exception e) {
             logger.error("error while parse date:" + date, e);
         }
@@ -141,11 +219,22 @@ public final class DateUtils {
     /**
      * convert date str to yyyy-MM-dd HH:mm:ss format
      *
-     * @param str date string
+     * @param date date string
      * @return yyyy-MM-dd HH:mm:ss format
      */
-    public static Date stringToDate(String str) {
-        return parse(str, Constants.YYYY_MM_DD_HH_MM_SS);
+    public static Date stringToDate(String date) {
+        return parse(date, YYYY_MM_DD_HH_MM_SS, null);
+    }
+
+    /**
+     * convert date str to yyyy-MM-dd HH:mm:ss format
+     *
+     * @param date date string
+     * @param timezone
+     * @return yyyy-MM-dd HH:mm:ss format
+     */
+    public static Date stringToDate(String date, String timezone) {
+        return parse(date, YYYY_MM_DD_HH_MM_SS, timezone);
     }
 
     /**
@@ -177,7 +266,7 @@ public final class DateUtils {
      * get the date of the specified date in the days before and after
      *
      * @param date date
-     * @param day day
+     * @param day  day
      * @return the date of the specified date in the days before and after
      */
     public static Date getSomeDay(Date date, int day) {
@@ -203,7 +292,7 @@ public final class DateUtils {
      * compare two dates
      *
      * @param future future date
-     * @param old old date
+     * @param old    old date
      * @return true if future time greater than old time
      */
     public static boolean compare(Date future, Date old) {
@@ -329,7 +418,7 @@ public final class DateUtils {
     /**
      * get some hour of day
      *
-     * @param date date
+     * @param date       date
      * @param offsetHour hours
      * @return some hour of day
      */
@@ -431,16 +520,15 @@ public final class DateUtils {
      * @return current date
      */
     public static Date getCurrentDate() {
-        return DateUtils.parse(DateUtils.getCurrentTime(),
-                Constants.YYYY_MM_DD_HH_MM_SS);
+        return new Date();
     }
 
     /**
      * get date
      *
-     * @param date date
+     * @param date          date
      * @param calendarField calendarField
-     * @param amount amount
+     * @param amount        amount
      * @return date
      */
     public static Date add(final Date date, final int calendarField, final int amount) {
@@ -457,7 +545,7 @@ public final class DateUtils {
      * starting from the current time, get how many seconds are left before the target time.
      * targetTime = baseTime + intervalSeconds
      *
-     * @param baseTime base time
+     * @param baseTime        base time
      * @param intervalSeconds a period of time
      * @return the number of seconds
      */
@@ -480,17 +568,24 @@ public final class DateUtils {
 
     /**
      * transform date to target timezone date
-     * <p>e.g.
-     * <p> if input date is 2020-01-01 00:00:00 current timezone is CST
-     * <p>targetTimezoneId is MST
-     * <p>this method will return 2020-01-01 15:00:00
+     * sourceTimeZoneId is system default timezone
      */
-    public static Date getTimezoneDate(Date date, String targetTimezoneId) {
-        if (StringUtils.isEmpty(targetTimezoneId)) {
+    public static Date transformTimezoneDate(Date date, String targetTimezoneId) {
+        return transformTimezoneDate(date, ZoneId.systemDefault().getId(), targetTimezoneId);
+    }
+
+    /**
+     * transform date from source timezone date to target timezone date
+     * <p>e.g.
+     * <p> if input date is `Thu Apr 28 10:00:00 UTC 2022`, sourceTimezoneId is UTC
+     * <p>targetTimezoneId is Asia/Shanghai
+     * <p>this method will return `Thu Apr 28 02:00:00 UTC 2022`
+     */
+    public static Date transformTimezoneDate(Date date, String sourceTimezoneId, String targetTimezoneId) {
+        if (StringUtils.isEmpty(sourceTimezoneId) || StringUtils.isEmpty(targetTimezoneId)) {
             return date;
         }
-
-        String dateToString = dateToString(date);
+        String dateToString = dateToString(date, sourceTimezoneId);
         LocalDateTime localDateTime = LocalDateTime.parse(dateToString, DateTimeFormatter.ofPattern(Constants.YYYY_MM_DD_HH_MM_SS));
         ZonedDateTime zonedDateTime = ZonedDateTime.of(localDateTime, TimeZone.getTimeZone(targetTimezoneId).toZoneId());
         return Date.from(zonedDateTime.toInstant());
