@@ -22,12 +22,13 @@ import org.apache.dolphinscheduler.common.graph.DAG;
 import org.apache.dolphinscheduler.common.model.TaskNode;
 import org.apache.dolphinscheduler.common.model.TaskNodeRelation;
 import org.apache.dolphinscheduler.common.process.ProcessDag;
-import org.apache.dolphinscheduler.common.task.conditions.ConditionsParameters;
-import org.apache.dolphinscheduler.common.task.switchtask.SwitchParameters;
-import org.apache.dolphinscheduler.common.task.switchtask.SwitchResultVo;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.dao.entity.ProcessTaskRelation;
 import org.apache.dolphinscheduler.dao.entity.TaskInstance;
+import org.apache.dolphinscheduler.plugin.task.api.TaskConstants;
+import org.apache.dolphinscheduler.plugin.task.api.model.SwitchResultVo;
+import org.apache.dolphinscheduler.plugin.task.api.parameters.ConditionsParameters;
+import org.apache.dolphinscheduler.plugin.task.api.parameters.SwitchParameters;
 
 import org.apache.commons.collections.CollectionUtils;
 
@@ -38,8 +39,9 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import java.util.stream.Collectors;
+import java.util.Optional;
 
+import org.apache.dolphinscheduler.spi.utils.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -110,7 +112,7 @@ public class DagHelper {
                 List<TaskNode> childNodeList = new ArrayList<>();
                 if (startNode == null) {
                     logger.error("start node name [{}] is not in task node list [{}] ",
-                            startNodeCode,
+                        startNodeCode,
                             taskNodeList
                     );
                     continue;
@@ -364,28 +366,32 @@ public class DagHelper {
         TaskInstance taskInstance = completeTaskList.get(nodeCode);
         ConditionsParameters conditionsParameters =
                 JSONUtils.parseObject(taskNode.getConditionResult(), ConditionsParameters.class);
-        if (conditionsParameters == null) {
-            return conditionTaskList;
-        }
         List<String> skipNodeList = new ArrayList<>();
         if (taskInstance.getState().typeIsSuccess()) {
-            conditionTaskList = conditionsParameters.getSuccessNode().stream().map(String::valueOf).collect(Collectors.toList());
-            skipNodeList = conditionsParameters.getFailedNode().stream().map(String::valueOf).collect(Collectors.toList());
+            conditionTaskList = conditionsParameters.getSuccessNode();
+            skipNodeList = conditionsParameters.getFailedNode();
         } else if (taskInstance.getState().typeIsFailure()) {
-            conditionTaskList = conditionsParameters.getFailedNode().stream().map(String::valueOf).collect(Collectors.toList());
-            skipNodeList = conditionsParameters.getSuccessNode().stream().map(String::valueOf).collect(Collectors.toList());
+            conditionTaskList = conditionsParameters.getFailedNode();
+            skipNodeList = conditionsParameters.getSuccessNode();
         } else {
             conditionTaskList.add(nodeCode);
         }
+        // the skipNodeList maybe null if no next task
+        skipNodeList = Optional.ofNullable(skipNodeList).orElse(new ArrayList<>());
         for (String failedNode : skipNodeList) {
             setTaskNodeSkip(failedNode, dag, completeTaskList, skipTaskNodeList);
         }
+        // the conditionTaskList maybe null if no next task
+        conditionTaskList = Optional.ofNullable(conditionTaskList).orElse(new ArrayList<>());
         return conditionTaskList;
     }
 
     /**
      * parse condition task find the branch process
      * set skip flag for another one.
+     *
+     * @param nodeCode
+     * @return
      */
     public static List<String> parseSwitchTask(String nodeCode,
                                                Map<String, TaskNode> skipTaskNodeList,
@@ -399,28 +405,27 @@ public class DagHelper {
         if (!completeTaskList.containsKey(nodeCode)) {
             return conditionTaskList;
         }
-        conditionTaskList.add(String.valueOf(skipTaskNode4Switch(taskNode, skipTaskNodeList, completeTaskList, dag)));
+        conditionTaskList = skipTaskNode4Switch(taskNode, skipTaskNodeList, completeTaskList, dag);
         return conditionTaskList;
     }
 
-    private static Long skipTaskNode4Switch(TaskNode taskNode, Map<String, TaskNode> skipTaskNodeList,
-                                            Map<String, TaskInstance> completeTaskList,
-                                            DAG<String, TaskNode, TaskNodeRelation> dag) {
+    private static List<String> skipTaskNode4Switch(TaskNode taskNode, Map<String, TaskNode> skipTaskNodeList,
+                                                    Map<String, TaskInstance> completeTaskList,
+                                                    DAG<String, TaskNode, TaskNodeRelation> dag) {
 
         SwitchParameters switchParameters = completeTaskList.get(Long.toString(taskNode.getCode())).getSwitchDependency();
         int resultConditionLocation = switchParameters.getResultConditionLocation();
         List<SwitchResultVo> conditionResultVoList = switchParameters.getDependTaskList();
-        Long switchTaskList = conditionResultVoList.get(resultConditionLocation).getNextNode();
-        if (switchTaskList == null) {
-            switchTaskList = 0L;
+        List<String> switchTaskList = conditionResultVoList.get(resultConditionLocation).getNextNode();
+        if (CollectionUtils.isEmpty(switchTaskList)) {
+            switchTaskList = new ArrayList<>();
         }
         conditionResultVoList.remove(resultConditionLocation);
         for (SwitchResultVo info : conditionResultVoList) {
-            Long nextNode = info.getNextNode();
-            if (nextNode == null || nextNode == 0L) {
+            if (CollectionUtils.isEmpty(info.getNextNode())) {
                 continue;
             }
-            setTaskNodeSkip(String.valueOf(nextNode), dag, completeTaskList, skipTaskNodeList);
+            setTaskNodeSkip(info.getNextNode().get(0), dag, completeTaskList, skipTaskNodeList);
         }
         return switchTaskList;
     }
@@ -536,19 +541,7 @@ public class DagHelper {
     public static boolean haveConditionsAfterNode(String parentNodeCode,
                                                   DAG<String, TaskNode, TaskNodeRelation> dag
     ) {
-        boolean result = false;
-        Set<String> subsequentNodes = dag.getSubsequentNodes(parentNodeCode);
-        if (CollectionUtils.isEmpty(subsequentNodes)) {
-            return result;
-        }
-        for (String nodeCode : subsequentNodes) {
-            TaskNode taskNode = dag.getNode(nodeCode);
-            List<String> preTasksList = JSONUtils.toList(taskNode.getPreTasks(), String.class);
-            if (preTasksList.contains(parentNodeCode) && taskNode.isConditionsTask()) {
-                return true;
-            }
-        }
-        return result;
+        return haveSubAfterNode(parentNodeCode, dag, TaskConstants.TASK_TYPE_CONDITIONS);
     }
 
     /**
@@ -566,4 +559,42 @@ public class DagHelper {
         }
         return false;
     }
+
+
+    /**
+     * is there have blocking node after the parent node
+     */
+    public static boolean haveBlockingAfterNode(String parentNodeCode,
+                                                DAG<String,TaskNode,TaskNodeRelation> dag) {
+        return haveSubAfterNode(parentNodeCode, dag, TaskConstants.TASK_TYPE_BLOCKING);
+    }
+
+    /**
+     * is there have all node after the parent node
+     */
+    public static boolean haveAllNodeAfterNode(String parentNodeCode,
+                                               DAG<String,TaskNode,TaskNodeRelation> dag) {
+        return haveSubAfterNode(parentNodeCode, dag, null);
+    }
+
+    /**
+     * Whether there is a specified type of child node after the parent node
+     */
+    public static boolean haveSubAfterNode(String parentNodeCode,
+                                           DAG<String,TaskNode,TaskNodeRelation> dag, String filterNodeType) {
+        Set<String> subsequentNodes = dag.getSubsequentNodes(parentNodeCode);
+        if (CollectionUtils.isEmpty(subsequentNodes)) {
+            return false;
+        }
+        if (StringUtils.isBlank(filterNodeType)){
+            return true;
+        }
+        for (String nodeName : subsequentNodes) {
+            TaskNode taskNode = dag.getNode(nodeName);
+            if (taskNode.getType().equalsIgnoreCase(filterNodeType)){
+                return true;
+            }
+        }
+        return false;
+    }
 }
