@@ -20,6 +20,7 @@ package org.apache.dolphinscheduler.plugin.datasource.oracle;
 import org.apache.dolphinscheduler.plugin.datasource.api.client.CommonDataSourceClient;
 import org.apache.dolphinscheduler.spi.datasource.BaseConnectionParam;
 import org.apache.dolphinscheduler.spi.enums.DbType;
+import org.apache.dolphinscheduler.spi.utils.Constants;
 
 public class OracleDataSourceClient extends CommonDataSourceClient {
 
@@ -27,4 +28,9 @@ public class OracleDataSourceClient extends CommonDataSourceClient {
         super(baseConnectionParam, dbType);
     }
 
+    @Override
+    protected void setDefaultValidationQuery(BaseConnectionParam baseConnectionParam) {
+        baseConnectionParam.setValidationQuery(Constants.ORACLE_VALIDATION_QUERY);
+    }
+
 }
