@@ -64,78 +64,45 @@ public enum CommandType {
     MASTER_RESPONSE,
 
     /**
-     * execute task request
+     * dispatch task request
      */
-    TASK_EXECUTE_REQUEST,
+    TASK_DISPATCH_REQUEST,
 
     /**
-     * execute task ack
+     * task execute running, from worker to master
      */
-    TASK_EXECUTE_ACK,
+    TASK_EXECUTE_RUNNING,
 
     /**
-     * execute task response
+     * task execute running ack, from master to worker
      */
-    TASK_EXECUTE_RESPONSE,
+    TASK_EXECUTE_RUNNING_ACK,
 
     /**
-     * db task ack
+     * task execute response, from worker to master
      */
-    DB_TASK_ACK,
+    TASK_EXECUTE_RESULT,
 
     /**
-     * db task response
+     * task execute response ack, from master to worker
      */
-    DB_TASK_RESPONSE,
+    TASK_EXECUTE_RESULT_ACK,
 
-    /**
-     * kill task
-     */
     TASK_KILL_REQUEST,
 
-    /**
-     * kill task response
-     */
     TASK_KILL_RESPONSE,
 
-    /**
-     * kill task response ack
-     */
-    TASK_KILL_RESPONSE_ACK,
-
-    /**
-     * task recall
-     */
-    TASK_RECALL,
-
-    /**
-     * task recall ack
-     */
-    TASK_RECALL_ACK,
-
     /**
      * HEART_BEAT
      */
     HEART_BEAT,
 
-    /**
-     * ping
-     */
     PING,
 
-    /**
-     * pong
-     */
     PONG,
 
-    /**
-     * alert send request
-     */
     ALERT_SEND_REQUEST,
 
-    /**
-     * alert send response
-     */
     ALERT_SEND_RESPONSE,
 
     /**
@@ -152,9 +119,26 @@ public enum CommandType {
      * state event request
      */
     STATE_EVENT_REQUEST,
-
     /**
      * cache expire
      */
-    CACHE_EXPIRE;
+    CACHE_EXPIRE,
+    /**
+     * task state event request
+     */
+    TASK_FORCE_STATE_EVENT_REQUEST,
+    /**
+     * task state event request
+     */
+    TASK_WAKEUP_EVENT_REQUEST,
+
+    /**
+     * workflow executing data request, from api to master
+     */
+    WORKFLOW_EXECUTING_DATA_REQUEST,
+
+    /**
+     * workflow executing data response, from master to api
+     */
+    WORKFLOW_EXECUTING_DATA_RESPONSE;
 }
