@@ -17,30 +17,33 @@
 
 package org.apache.dolphinscheduler.remote;
 
-import io.netty.channel.Channel;
 import org.apache.dolphinscheduler.remote.command.Command;
 import org.apache.dolphinscheduler.remote.command.CommandType;
-import org.apache.dolphinscheduler.remote.command.Ping;
-import org.apache.dolphinscheduler.remote.command.Pong;
 import org.apache.dolphinscheduler.remote.config.NettyClientConfig;
 import org.apache.dolphinscheduler.remote.config.NettyServerConfig;
 import org.apache.dolphinscheduler.remote.future.InvokeCallback;
 import org.apache.dolphinscheduler.remote.future.ResponseFuture;
 import org.apache.dolphinscheduler.remote.processor.NettyRequestProcessor;
 import org.apache.dolphinscheduler.remote.utils.Host;
-import org.junit.Assert;
-import org.junit.Test;
 
+import java.io.Serializable;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.atomic.AtomicLong;
 
+import org.junit.Assert;
+import org.junit.Test;
+
+import io.netty.buffer.ByteBuf;
+import io.netty.buffer.Unpooled;
+import io.netty.channel.Channel;
+
 /**
- * netty remote client test
+ *  netty remote client test
  */
 public class NettyRemotingClientTest {
 
     /**
-     * test send sync
+     *  test send sync
      */
     @Test
     public void testSendSync() {
@@ -71,10 +74,10 @@ public class NettyRemotingClientTest {
     }
 
     /**
-     * test sned async
+     *  test sned async
      */
     @Test
-    public void testSendAsync() {
+    public void testSendAsync(){
         NettyServerConfig serverConfig = new NettyServerConfig();
 
         NettyRemotingServer server = new NettyRemotingServer(serverConfig);
@@ -107,4 +110,100 @@ public class NettyRemotingClientTest {
         server.close();
         client.close();
     }
+
+    private static class Ping implements Serializable {
+
+        /**
+         * ping body
+         */
+        protected static final ByteBuf EMPTY_BODY = Unpooled.EMPTY_BUFFER;
+
+        /**
+         * request command body
+         */
+        private static final byte[] EMPTY_BODY_ARRAY = new byte[0];
+
+        private static final ByteBuf PING_BUF;
+
+        static {
+            ByteBuf ping = Unpooled.buffer();
+            ping.writeByte(Command.MAGIC);
+            ping.writeByte(CommandType.PING.ordinal());
+            ping.writeLong(0);
+            ping.writeInt(0);
+            ping.writeBytes(EMPTY_BODY);
+            PING_BUF = Unpooled.unreleasableBuffer(ping).asReadOnly();
+        }
+
+        /**
+         * ping content
+         *
+         * @return result
+         */
+        public static ByteBuf pingContent() {
+            return PING_BUF.duplicate();
+        }
+
+        /**
+         * create ping command
+         *
+         * @return command
+         */
+        public static Command create() {
+            Command command = new Command();
+            command.setType(CommandType.PING);
+            command.setBody(EMPTY_BODY_ARRAY);
+            return command;
+        }
+    }
+
+    private static class Pong implements Serializable {
+
+        /**
+         * pong body
+         */
+        protected static final ByteBuf EMPTY_BODY = Unpooled.EMPTY_BUFFER;
+
+        /**
+         * pong command body
+         */
+        private static final byte[] EMPTY_BODY_ARRAY = new byte[0];
+
+        /**
+         * pong byte buffer
+         */
+        private static final ByteBuf PONG_BUF;
+
+        static {
+            ByteBuf ping = Unpooled.buffer();
+            ping.writeByte(Command.MAGIC);
+            ping.writeByte(CommandType.PONG.ordinal());
+            ping.writeLong(0);
+            ping.writeInt(0);
+            ping.writeBytes(EMPTY_BODY);
+            PONG_BUF = Unpooled.unreleasableBuffer(ping).asReadOnly();
+        }
+
+        /**
+         * pong content
+         *
+         * @return result
+         */
+        public static ByteBuf pongContent() {
+            return PONG_BUF.duplicate();
+        }
+
+        /**
+         * package pong command
+         *
+         * @param opaque request unique identification
+         * @return command
+         */
+        public static Command create(long opaque) {
+            Command command = new Command(opaque);
+            command.setType(CommandType.PONG);
+            command.setBody(EMPTY_BODY_ARRAY);
+            return command;
+        }
+    }
 }
