@@ -26,29 +26,36 @@ import static org.mockito.ArgumentMatchers.any;
 import org.apache.dolphinscheduler.common.Constants;
 import org.apache.dolphinscheduler.common.enums.CommandType;
 import org.apache.dolphinscheduler.common.enums.Flag;
-import org.apache.dolphinscheduler.common.enums.TaskType;
+import org.apache.dolphinscheduler.common.enums.ProcessExecutionTypeEnum;
+import org.apache.dolphinscheduler.common.enums.TaskGroupQueueStatus;
 import org.apache.dolphinscheduler.common.enums.UserType;
 import org.apache.dolphinscheduler.common.enums.WarningType;
 import org.apache.dolphinscheduler.common.graph.DAG;
 import org.apache.dolphinscheduler.common.model.TaskNode;
 import org.apache.dolphinscheduler.common.model.TaskNodeRelation;
-import org.apache.dolphinscheduler.common.process.ResourceInfo;
-import org.apache.dolphinscheduler.common.task.spark.SparkParameters;
 import org.apache.dolphinscheduler.common.utils.DateUtils;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.dao.entity.Command;
+import org.apache.dolphinscheduler.dao.entity.DqExecuteResult;
+import org.apache.dolphinscheduler.dao.entity.DqRule;
+import org.apache.dolphinscheduler.dao.entity.DqRuleExecuteSql;
+import org.apache.dolphinscheduler.dao.entity.DqRuleInputEntry;
 import org.apache.dolphinscheduler.dao.entity.ProcessDefinition;
 import org.apache.dolphinscheduler.dao.entity.ProcessDefinitionLog;
 import org.apache.dolphinscheduler.dao.entity.ProcessInstance;
 import org.apache.dolphinscheduler.dao.entity.ProcessInstanceMap;
-import org.apache.dolphinscheduler.dao.entity.ProcessTaskRelation;
 import org.apache.dolphinscheduler.dao.entity.ProcessTaskRelationLog;
 import org.apache.dolphinscheduler.dao.entity.Resource;
-import org.apache.dolphinscheduler.dao.entity.TaskDefinition;
 import org.apache.dolphinscheduler.dao.entity.TaskDefinitionLog;
+import org.apache.dolphinscheduler.dao.entity.TaskGroupQueue;
 import org.apache.dolphinscheduler.dao.entity.TaskInstance;
 import org.apache.dolphinscheduler.dao.entity.User;
 import org.apache.dolphinscheduler.dao.mapper.CommandMapper;
+import org.apache.dolphinscheduler.dao.mapper.DqComparisonTypeMapper;
+import org.apache.dolphinscheduler.dao.mapper.DqExecuteResultMapper;
+import org.apache.dolphinscheduler.dao.mapper.DqRuleExecuteSqlMapper;
+import org.apache.dolphinscheduler.dao.mapper.DqRuleInputEntryMapper;
+import org.apache.dolphinscheduler.dao.mapper.DqRuleMapper;
 import org.apache.dolphinscheduler.dao.mapper.ErrorCommandMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProcessDefinitionLogMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProcessDefinitionMapper;
@@ -56,23 +63,34 @@ import org.apache.dolphinscheduler.dao.mapper.ProcessInstanceMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProcessTaskRelationLogMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProcessTaskRelationMapper;
 import org.apache.dolphinscheduler.dao.mapper.ResourceMapper;
+import org.apache.dolphinscheduler.dao.mapper.ScheduleMapper;
 import org.apache.dolphinscheduler.dao.mapper.TaskDefinitionLogMapper;
 import org.apache.dolphinscheduler.dao.mapper.TaskDefinitionMapper;
+import org.apache.dolphinscheduler.dao.mapper.TaskGroupMapper;
+import org.apache.dolphinscheduler.dao.mapper.TaskGroupQueueMapper;
 import org.apache.dolphinscheduler.dao.mapper.TaskInstanceMapper;
 import org.apache.dolphinscheduler.dao.mapper.UserMapper;
+import org.apache.dolphinscheduler.plugin.task.api.enums.dp.DqTaskState;
+import org.apache.dolphinscheduler.plugin.task.api.enums.dp.ExecuteSqlType;
+import org.apache.dolphinscheduler.plugin.task.api.enums.dp.InputType;
+import org.apache.dolphinscheduler.plugin.task.api.enums.dp.OptionSourceType;
+import org.apache.dolphinscheduler.plugin.task.api.enums.dp.ValueType;
+import org.apache.dolphinscheduler.plugin.task.api.model.ResourceInfo;
+import org.apache.dolphinscheduler.service.exceptions.ServiceException;
 import org.apache.dolphinscheduler.service.quartz.cron.CronUtilsTest;
+import org.apache.dolphinscheduler.spi.params.base.FormType;
 
 import java.util.ArrayList;
-import java.util.Arrays;
+import java.util.Collections;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.stream.Collectors;
-import java.util.stream.Stream;
 
 import org.junit.Assert;
+import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.ExpectedException;
 import org.junit.runner.RunWith;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
@@ -87,13 +105,16 @@ import com.fasterxml.jackson.databind.JsonNode;
 /**
  * process service test
  */
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class ProcessServiceTest {
 
     private static final Logger logger = LoggerFactory.getLogger(CronUtilsTest.class);
 
+    @Rule
+    public final ExpectedException exception = ExpectedException.none();
+
     @InjectMocks
-    private ProcessService processService;
+    private ProcessServiceImpl processService;
     @Mock
     private CommandMapper commandMapper;
     @Mock
@@ -118,6 +139,28 @@ public class ProcessServiceTest {
     private ProcessDefinitionLogMapper processDefineLogMapper;
     @Mock
     private ResourceMapper resourceMapper;
+    @Mock
+    private TaskGroupMapper taskGroupMapper;
+    @Mock
+    private TaskGroupQueueMapper taskGroupQueueMapper;
+
+    @Mock
+    private DqExecuteResultMapper dqExecuteResultMapper;
+
+    @Mock
+    private DqRuleMapper dqRuleMapper;
+
+    @Mock
+    private DqRuleInputEntryMapper dqRuleInputEntryMapper;
+
+    @Mock
+    private DqRuleExecuteSqlMapper dqRuleExecuteSqlMapper;
+
+    @Mock
+    private DqComparisonTypeMapper dqComparisonTypeMapper;
+
+    @Mock
+    private ScheduleMapper scheduleMapper;
 
     @Test
     public void testCreateSubCommand() {
@@ -142,6 +185,7 @@ public class ProcessServiceTest {
         parentInstance.setCommandType(CommandType.START_PROCESS);
         ProcessDefinition processDefinition = new ProcessDefinition();
         processDefinition.setCode(10L);
+        Mockito.when(processDefineMapper.queryByDefineId(100)).thenReturn(processDefinition);
         Mockito.when(processDefineMapper.queryByCode(10L)).thenReturn(processDefinition);
         command = processService.createSubProcessCommand(parentInstance, childInstance, instanceMap, task);
         Assert.assertEquals(CommandType.START_PROCESS, command.getCommandType());
@@ -243,9 +287,17 @@ public class ProcessServiceTest {
         Command command = new Command();
         command.setProcessDefinitionCode(222);
         command.setCommandType(CommandType.REPEAT_RUNNING);
-        command.setCommandParam("{\"" + CMD_PARAM_RECOVER_PROCESS_ID_STRING + "\":\"111\",\""
-                + CMD_PARAM_SUB_PROCESS_DEFINE_CODE + "\":\"222\"}");
-        Assert.assertNull(processService.handleCommand(logger, host, command));
+        command.setCommandParam("{\""
+                                    + CMD_PARAM_RECOVER_PROCESS_ID_STRING
+                                    + "\":\"111\",\""
+                                    + CMD_PARAM_SUB_PROCESS_DEFINE_CODE
+                                    + "\":\"222\"}");
+        try {
+            Assert.assertNull(processService.handleCommand(host, command));
+        } catch (IllegalArgumentException illegalArgumentException) {
+            // assert throw illegalArgumentException here since the definition is null
+            Assert.assertTrue(true);
+        }
 
         int definitionVersion = 1;
         long definitionCode = 123;
@@ -265,14 +317,22 @@ public class ProcessServiceTest {
         processDefinition.setVersion(definitionVersion);
         processDefinition.setCode(definitionCode);
         processDefinition.setGlobalParams("[{\"prop\":\"startParam1\",\"direct\":\"IN\",\"type\":\"VARCHAR\",\"value\":\"\"}]");
+        processDefinition.setExecutionType(ProcessExecutionTypeEnum.PARALLEL);
+
         ProcessInstance processInstance = new ProcessInstance();
+        processInstance.setId(222);
+        processInstance.setProcessDefinitionCode(11L);
+        processInstance.setHost("127.0.0.1:5678");
+        processInstance.setProcessDefinitionVersion(1);
         processInstance.setId(processInstanceId);
         processInstance.setProcessDefinitionCode(definitionCode);
         processInstance.setProcessDefinitionVersion(definitionVersion);
+
+        Mockito.when(processDefineMapper.queryByCode(command1.getProcessDefinitionCode())).thenReturn(processDefinition);
         Mockito.when(processDefineLogMapper.queryByDefinitionCodeAndVersion(processInstance.getProcessDefinitionCode(),
                 processInstance.getProcessDefinitionVersion())).thenReturn(new ProcessDefinitionLog(processDefinition));
         Mockito.when(processInstanceMapper.queryDetailById(222)).thenReturn(processInstance);
-        Assert.assertNotNull(processService.handleCommand(logger, host, command1));
+        Assert.assertNotNull(processService.handleCommand(host, command1));
 
         Command command2 = new Command();
         command2.setId(2);
@@ -282,7 +342,7 @@ public class ProcessServiceTest {
         command2.setCommandType(CommandType.RECOVER_SUSPENDED_PROCESS);
         command2.setProcessInstanceId(processInstanceId);
         Mockito.when(commandMapper.deleteById(2)).thenReturn(1);
-        Assert.assertNotNull(processService.handleCommand(logger, host, command2));
+        Assert.assertNotNull(processService.handleCommand(host, command2));
 
         Command command3 = new Command();
         command3.setId(3);
@@ -292,7 +352,7 @@ public class ProcessServiceTest {
         command3.setCommandParam("{\"WaitingThreadInstanceId\":222}");
         command3.setCommandType(CommandType.START_FAILURE_TASK_PROCESS);
         Mockito.when(commandMapper.deleteById(3)).thenReturn(1);
-        Assert.assertNotNull(processService.handleCommand(logger, host, command3));
+        Assert.assertNotNull(processService.handleCommand(host, command3));
 
         Command command4 = new Command();
         command4.setId(4);
@@ -302,7 +362,7 @@ public class ProcessServiceTest {
         command4.setCommandType(CommandType.REPEAT_RUNNING);
         command4.setProcessInstanceId(processInstanceId);
         Mockito.when(commandMapper.deleteById(4)).thenReturn(1);
-        Assert.assertNotNull(processService.handleCommand(logger, host, command4));
+        Assert.assertNotNull(processService.handleCommand(host, command4));
 
         Command command5 = new Command();
         command5.setId(5);
@@ -316,9 +376,127 @@ public class ProcessServiceTest {
         command5.setCommandType(CommandType.START_PROCESS);
         command5.setDryRun(Constants.DRY_RUN_FLAG_NO);
         Mockito.when(commandMapper.deleteById(5)).thenReturn(1);
-
-        ProcessInstance processInstance1 = processService.handleCommand(logger, host, command5);
+        ProcessInstance processInstance1 = processService.handleCommand(host, command5);
         Assert.assertTrue(processInstance1.getGlobalParams().contains("\"testStartParam1\""));
+
+        ProcessDefinition processDefinition1 = new ProcessDefinition();
+        processDefinition1.setId(123);
+        processDefinition1.setName("test");
+        processDefinition1.setVersion(1);
+        processDefinition1.setCode(11L);
+        processDefinition1.setVersion(1);
+        processDefinition1.setExecutionType(ProcessExecutionTypeEnum.SERIAL_WAIT);
+        List<ProcessInstance> lists = new ArrayList<>();
+        ProcessInstance processInstance11 = new ProcessInstance();
+        processInstance11.setId(222);
+        processInstance11.setProcessDefinitionCode(11L);
+        processInstance11.setProcessDefinitionVersion(1);
+        processInstance11.setHost("127.0.0.1:5678");
+        lists.add(processInstance11);
+
+        ProcessInstance processInstance2 = new ProcessInstance();
+        processInstance2.setId(223);
+        processInstance2.setProcessDefinitionCode(11L);
+        processInstance2.setProcessDefinitionVersion(1);
+        Mockito.when(processInstanceMapper.queryDetailById(223)).thenReturn(processInstance2);
+        Mockito.when(processDefineMapper.queryByCode(11L)).thenReturn(processDefinition1);
+        Mockito.when(commandMapper.deleteById(1)).thenReturn(1);
+        Assert.assertNotNull(processService.handleCommand(host, command1));
+
+        Command command6 = new Command();
+        command6.setId(6);
+        command6.setProcessDefinitionCode(11L);
+        command6.setCommandParam("{\"ProcessInstanceId\":223}");
+        command6.setCommandType(CommandType.RECOVER_SERIAL_WAIT);
+        command6.setProcessDefinitionVersion(1);
+        Mockito.when(processInstanceMapper.queryByProcessDefineCodeAndProcessDefinitionVersionAndStatusAndNextId(11L, 1, Constants.RUNNING_PROCESS_STATE, 223)).thenReturn(lists);
+        Mockito.when(processInstanceMapper.updateNextProcessIdById(223, 222)).thenReturn(true);
+        Mockito.when(commandMapper.deleteById(6)).thenReturn(1);
+        ProcessInstance processInstance6 = processService.handleCommand(host, command6);
+        Assert.assertTrue(processInstance6 != null);
+
+        processDefinition1.setExecutionType(ProcessExecutionTypeEnum.SERIAL_DISCARD);
+        Mockito.when(processDefineMapper.queryByCode(11L)).thenReturn(processDefinition1);
+        ProcessInstance processInstance7 = new ProcessInstance();
+        processInstance7.setId(224);
+        processInstance7.setProcessDefinitionCode(11L);
+        processInstance7.setProcessDefinitionVersion(1);
+        Mockito.when(processInstanceMapper.queryDetailById(224)).thenReturn(processInstance7);
+
+        Command command7 = new Command();
+        command7.setId(7);
+        command7.setProcessDefinitionCode(11L);
+        command7.setCommandParam("{\"ProcessInstanceId\":224}");
+        command7.setCommandType(CommandType.RECOVER_SERIAL_WAIT);
+        command7.setProcessDefinitionVersion(1);
+        Mockito.when(commandMapper.deleteById(7)).thenReturn(1);
+        Mockito.when(processInstanceMapper.queryByProcessDefineCodeAndProcessDefinitionVersionAndStatusAndNextId(11L, 1, Constants.RUNNING_PROCESS_STATE, 224)).thenReturn(null);
+        ProcessInstance processInstance8 = processService.handleCommand(host, command7);
+        Assert.assertTrue(processInstance8 == null);
+
+        ProcessDefinition processDefinition2 = new ProcessDefinition();
+        processDefinition2.setId(123);
+        processDefinition2.setName("test");
+        processDefinition2.setVersion(1);
+        processDefinition2.setCode(12L);
+        processDefinition2.setExecutionType(ProcessExecutionTypeEnum.SERIAL_PRIORITY);
+        Mockito.when(processDefineMapper.queryByCode(12L)).thenReturn(processDefinition2);
+        ProcessInstance processInstance9 = new ProcessInstance();
+        processInstance9.setId(225);
+        processInstance9.setProcessDefinitionCode(11L);
+        processInstance9.setProcessDefinitionVersion(1);
+        Command command9 = new Command();
+        command9.setId(9);
+        command9.setProcessDefinitionCode(12L);
+        command9.setCommandParam("{\"ProcessInstanceId\":225}");
+        command9.setCommandType(CommandType.RECOVER_SERIAL_WAIT);
+        command9.setProcessDefinitionVersion(1);
+        Mockito.when(processInstanceMapper.queryDetailById(225)).thenReturn(processInstance9);
+        Mockito.when(processInstanceMapper.queryByProcessDefineCodeAndProcessDefinitionVersionAndStatusAndNextId(12L, 1, Constants.RUNNING_PROCESS_STATE, 0)).thenReturn(lists);
+        Mockito.when(processInstanceMapper.updateById(processInstance)).thenReturn(1);
+        Mockito.when(commandMapper.deleteById(9)).thenReturn(1);
+        ProcessInstance processInstance10 = processService.handleCommand(host, command9);
+        Assert.assertTrue(processInstance10 == null);
+    }
+
+    @Test(expected = ServiceException.class)
+    public void testDeleteNotExistCommand() {
+        String host = "127.0.0.1";
+        int definitionVersion = 1;
+        long definitionCode = 123;
+        int processInstanceId = 222;
+
+        Command command1 = new Command();
+        command1.setId(1);
+        command1.setProcessDefinitionCode(definitionCode);
+        command1.setProcessDefinitionVersion(definitionVersion);
+        command1.setCommandParam("{\"ProcessInstanceId\":222}");
+        command1.setCommandType(CommandType.START_PROCESS);
+
+        ProcessDefinition processDefinition = new ProcessDefinition();
+        processDefinition.setId(123);
+        processDefinition.setName("test");
+        processDefinition.setVersion(definitionVersion);
+        processDefinition.setCode(definitionCode);
+        processDefinition.setGlobalParams("[{\"prop\":\"startParam1\",\"direct\":\"IN\",\"type\":\"VARCHAR\",\"value\":\"\"}]");
+        processDefinition.setExecutionType(ProcessExecutionTypeEnum.PARALLEL);
+
+        ProcessInstance processInstance = new ProcessInstance();
+        processInstance.setId(222);
+        processInstance.setProcessDefinitionCode(11L);
+        processInstance.setHost("127.0.0.1:5678");
+        processInstance.setProcessDefinitionVersion(1);
+        processInstance.setId(processInstanceId);
+        processInstance.setProcessDefinitionCode(definitionCode);
+        processInstance.setProcessDefinitionVersion(definitionVersion);
+
+        Mockito.when(processDefineMapper.queryByCode(command1.getProcessDefinitionCode())).thenReturn(processDefinition);
+        Mockito.when(processDefineLogMapper.queryByDefinitionCodeAndVersion(processInstance.getProcessDefinitionCode(),
+                processInstance.getProcessDefinitionVersion())).thenReturn(new ProcessDefinitionLog(processDefinition));
+        Mockito.when(processInstanceMapper.queryDetailById(222)).thenReturn(processInstance);
+
+        // will throw exception when command id is 0 and delete fail
+        processService.handleCommand(host, command1);
     }
 
     @Test
@@ -356,6 +534,7 @@ public class ProcessServiceTest {
         ProcessDefinition processDefinition = new ProcessDefinition();
         processDefinition.setCode(parentProcessDefineCode);
         processDefinition.setVersion(parentProcessDefineVersion);
+        Mockito.when(processDefineMapper.selectById(parentProcessDefineId)).thenReturn(processDefinition);
 
         long postTaskCode = 2L;
         int postTaskVersion = 2;
@@ -365,7 +544,6 @@ public class ProcessServiceTest {
         processTaskRelationLog.setPostTaskCode(postTaskCode);
         processTaskRelationLog.setPostTaskVersion(postTaskVersion);
         relationLogList.add(processTaskRelationLog);
-        Mockito.when(processDefineMapper.queryByCode(parentProcessDefineCode)).thenReturn(processDefinition);
         Mockito.when(processTaskRelationLogMapper.queryByProcessCodeAndVersion(parentProcessDefineCode
                 , parentProcessDefineVersion)).thenReturn(relationLogList);
 
@@ -373,6 +551,7 @@ public class ProcessServiceTest {
         TaskDefinitionLog taskDefinitionLog1 = new TaskDefinitionLog();
         taskDefinitionLog1.setTaskParams("{\"processDefinitionCode\": 123L}");
         taskDefinitionLogs.add(taskDefinitionLog1);
+        Mockito.when(taskDefinitionLogMapper.queryByTaskDefinitions(Mockito.anySet())).thenReturn(taskDefinitionLogs);
 
         List<Long> ids = new ArrayList<>();
         processService.recurseFindSubProcess(parentProcessDefineCode, ids);
@@ -396,6 +575,102 @@ public class ProcessServiceTest {
     }
 
     @Test
+    public void getDqRule() {
+        Mockito.when(dqRuleMapper.selectById(1)).thenReturn(new DqRule());
+        Assert.assertNotNull(processService.getDqRule(1));
+    }
+
+    @Test
+    public void getRuleInputEntry() {
+        Mockito.when(dqRuleInputEntryMapper.getRuleInputEntryList(1)).thenReturn(getRuleInputEntryList());
+        Assert.assertNotNull(processService.getRuleInputEntry(1));
+    }
+
+    @Test
+    public void getDqExecuteSql() {
+        Mockito.when(dqRuleExecuteSqlMapper.getExecuteSqlList(1)).thenReturn(getRuleExecuteSqlList());
+        Assert.assertNotNull(processService.getDqExecuteSql(1));
+    }
+
+    private List<DqRuleInputEntry> getRuleInputEntryList() {
+        List<DqRuleInputEntry> list = new ArrayList<>();
+
+        DqRuleInputEntry srcConnectorType = new DqRuleInputEntry();
+        srcConnectorType.setTitle("源数据类型");
+        srcConnectorType.setField("src_connector_type");
+        srcConnectorType.setType(FormType.SELECT.getFormType());
+        srcConnectorType.setCanEdit(true);
+        srcConnectorType.setShow(true);
+        srcConnectorType.setValue("JDBC");
+        srcConnectorType.setPlaceholder("Please select the source connector type");
+        srcConnectorType.setOptionSourceType(OptionSourceType.DEFAULT.getCode());
+        srcConnectorType.setOptions("[{\"label\":\"HIVE\",\"value\":\"HIVE\"},{\"label\":\"JDBC\",\"value\":\"JDBC\"}]");
+        srcConnectorType.setInputType(InputType.DEFAULT.getCode());
+        srcConnectorType.setValueType(ValueType.NUMBER.getCode());
+        srcConnectorType.setEmit(true);
+
+        DqRuleInputEntry statisticsName = new DqRuleInputEntry();
+        statisticsName.setTitle("统计值名");
+        statisticsName.setField("statistics_name");
+        statisticsName.setType(FormType.INPUT.getFormType());
+        statisticsName.setCanEdit(true);
+        statisticsName.setShow(true);
+        statisticsName.setPlaceholder("Please enter statistics name, the alias in statistics execute sql");
+        statisticsName.setOptionSourceType(OptionSourceType.DEFAULT.getCode());
+        statisticsName.setInputType(InputType.DEFAULT.getCode());
+        statisticsName.setValueType(ValueType.STRING.getCode());
+        statisticsName.setEmit(false);
+
+        DqRuleInputEntry statisticsExecuteSql = new DqRuleInputEntry();
+        statisticsExecuteSql.setTitle("统计值计算SQL");
+        statisticsExecuteSql.setField("statistics_execute_sql");
+        statisticsExecuteSql.setType(FormType.TEXTAREA.getFormType());
+        statisticsExecuteSql.setCanEdit(true);
+        statisticsExecuteSql.setShow(true);
+        statisticsExecuteSql.setPlaceholder("Please enter the statistics execute sql");
+        statisticsExecuteSql.setOptionSourceType(OptionSourceType.DEFAULT.getCode());
+        statisticsExecuteSql.setValueType(ValueType.LIKE_SQL.getCode());
+        statisticsExecuteSql.setEmit(false);
+
+        list.add(srcConnectorType);
+        list.add(statisticsName);
+        list.add(statisticsExecuteSql);
+
+        return list;
+    }
+
+    private List<DqRuleExecuteSql> getRuleExecuteSqlList() {
+        List<DqRuleExecuteSql> list = new ArrayList<>();
+
+        DqRuleExecuteSql executeSqlDefinition = new DqRuleExecuteSql();
+        executeSqlDefinition.setIndex(0);
+        executeSqlDefinition.setSql("SELECT COUNT(*) AS total FROM ${src_table} WHERE (${src_filter})");
+        executeSqlDefinition.setTableAlias("total_count");
+        executeSqlDefinition.setType(ExecuteSqlType.COMPARISON.getCode());
+        list.add(executeSqlDefinition);
+
+        return list;
+    }
+
+    public DqExecuteResult getExecuteResult() {
+        DqExecuteResult dqExecuteResult = new DqExecuteResult();
+        dqExecuteResult.setId(1);
+        dqExecuteResult.setState(DqTaskState.FAILURE.getCode());
+
+        return dqExecuteResult;
+    }
+
+    public List<DqExecuteResult> getExecuteResultList() {
+
+        List<DqExecuteResult> list = new ArrayList<>();
+        DqExecuteResult dqExecuteResult = new DqExecuteResult();
+        dqExecuteResult.setId(1);
+        dqExecuteResult.setState(DqTaskState.FAILURE.getCode());
+        list.add(dqExecuteResult);
+
+        return list;
+    }
+
     public void testSaveTaskDefine() {
         User operator = new User();
         operator.setId(-1);
@@ -415,7 +690,7 @@ public class ProcessServiceTest {
         taskDefinition.setCode(751500437479424L);
         taskDefinition.setName("aa");
         taskDefinition.setProjectCode(751485690568704L);
-        taskDefinition.setTaskType(TaskType.SHELL.getDesc());
+        taskDefinition.setTaskType("SHELL");
         taskDefinition.setUserId(-1);
         taskDefinition.setVersion(1);
         taskDefinition.setCreateTime(new Date());
@@ -452,7 +727,7 @@ public class ProcessServiceTest {
         taskDefinition.setCode(3L);
         taskDefinition.setName("1-test");
         taskDefinition.setProjectCode(1L);
-        taskDefinition.setTaskType(TaskType.SHELL.getDesc());
+        taskDefinition.setTaskType("SHELL");
         taskDefinition.setUserId(1);
         taskDefinition.setVersion(2);
         taskDefinition.setCreateTime(new Date());
@@ -462,7 +737,7 @@ public class ProcessServiceTest {
         td2.setCode(2L);
         td2.setName("unit-test");
         td2.setProjectCode(1L);
-        td2.setTaskType(TaskType.SHELL.getDesc());
+        td2.setTaskType("SHELL");
         td2.setUserId(1);
         td2.setVersion(1);
         td2.setCreateTime(new Date());
@@ -507,89 +782,6 @@ public class ProcessServiceTest {
         processService.changeOutParam(taskInstance);
     }
 
-    @Test
-    public void testUpdateTaskDefinitionResources() throws Exception {
-        TaskDefinition taskDefinition = new TaskDefinition();
-        String taskParameters = "{\n"
-                + "    \"mainClass\": \"org.apache.dolphinscheduler.SparkTest\",\n"
-                + "    \"mainJar\": {\n"
-                + "        \"id\": 1\n"
-                + "    },\n"
-                + "    \"deployMode\": \"cluster\",\n"
-                + "    \"resourceList\": [\n"
-                + "        {\n"
-                + "            \"id\": 3\n"
-                + "        },\n"
-                + "        {\n"
-                + "            \"id\": 4\n"
-                + "        }\n"
-                + "    ],\n"
-                + "    \"localParams\": [],\n"
-                + "    \"driverCores\": 1,\n"
-                + "    \"driverMemory\": \"512M\",\n"
-                + "    \"numExecutors\": 2,\n"
-                + "    \"executorMemory\": \"2G\",\n"
-                + "    \"executorCores\": 2,\n"
-                + "    \"appName\": \"\",\n"
-                + "    \"mainArgs\": \"\",\n"
-                + "    \"others\": \"\",\n"
-                + "    \"programType\": \"JAVA\",\n"
-                + "    \"sparkVersion\": \"SPARK2\",\n"
-                + "    \"dependence\": {},\n"
-                + "    \"conditionResult\": {\n"
-                + "        \"successNode\": [\n"
-                + "            \"\"\n"
-                + "        ],\n"
-                + "        \"failedNode\": [\n"
-                + "            \"\"\n"
-                + "        ]\n"
-                + "    },\n"
-                + "    \"waitStartTimeout\": {}\n"
-                + "}";
-        taskDefinition.setTaskParams(taskParameters);
-
-        Map<Integer, Resource> resourceMap =
-                Stream.of(1, 3, 4)
-                        .map(i -> {
-                            Resource resource = new Resource();
-                            resource.setId(i);
-                            resource.setFileName("file" + i);
-                            resource.setFullName("/file" + i);
-                            return resource;
-                        })
-                        .collect(
-                                Collectors.toMap(
-                                        Resource::getId,
-                                        resource -> resource)
-                        );
-        for (Integer integer : Arrays.asList(1, 3, 4)) {
-            Mockito.when(resourceMapper.selectById(integer))
-                    .thenReturn(resourceMap.get(integer));
-        }
-
-        Whitebox.invokeMethod(processService,
-                "updateTaskDefinitionResources",
-                taskDefinition);
-
-        String taskParams = taskDefinition.getTaskParams();
-        SparkParameters sparkParameters = JSONUtils.parseObject(taskParams, SparkParameters.class);
-        ResourceInfo mainJar = sparkParameters.getMainJar();
-        Assert.assertEquals(1, mainJar.getId());
-        Assert.assertEquals("file1", mainJar.getRes());
-        Assert.assertEquals("/file1", mainJar.getResourceName());
-
-        Assert.assertEquals(2, sparkParameters.getResourceList().size());
-        ResourceInfo res1 = sparkParameters.getResourceList().get(0);
-        ResourceInfo res2 = sparkParameters.getResourceList().get(1);
-        Assert.assertEquals(3, res1.getId());
-        Assert.assertEquals("file3", res1.getRes());
-        Assert.assertEquals("/file3", res1.getResourceName());
-        Assert.assertEquals(4, res2.getId());
-        Assert.assertEquals("file4", res2.getRes());
-        Assert.assertEquals("/file4", res2.getResourceName());
-
-    }
-
     @Test
     public void testUpdateResourceInfo() throws Exception {
         // test if input is null
@@ -624,4 +816,67 @@ public class ProcessServiceTest {
 
     }
 
+    @Test
+    public void testCreateTaskGroupQueue() {
+        Mockito.when(taskGroupQueueMapper.insert(Mockito.any(TaskGroupQueue.class))).thenReturn(1);
+        TaskGroupQueue taskGroupQueue = processService.insertIntoTaskGroupQueue(1, "task name", 1, 1, 1, TaskGroupQueueStatus.WAIT_QUEUE);
+        Assert.assertNotNull(taskGroupQueue);
+    }
+
+    @Test
+    public void testDoRelease() {
+
+        TaskGroupQueue taskGroupQueue = getTaskGroupQueue();
+        TaskInstance taskInstance = new TaskInstance();
+        taskInstance.setId(1);
+        taskInstance.setProcessInstanceId(1);
+        taskInstance.setTaskGroupId(taskGroupQueue.getGroupId());
+
+        Mockito.when(taskGroupQueueMapper.queryByTaskId(1)).thenReturn(taskGroupQueue);
+        Mockito.when(taskGroupQueueMapper.updateById(taskGroupQueue)).thenReturn(1);
+
+        processService.releaseTaskGroup(taskInstance);
+
+    }
+
+    @Test
+    public void testFindTaskInstanceByIdList() {
+        List<Integer> emptyList = new ArrayList<>();
+        Mockito.when(taskInstanceMapper.selectBatchIds(emptyList)).thenReturn(new ArrayList<>());
+        Assert.assertEquals(0, processService.findTaskInstanceByIdList(emptyList).size());
+
+        List<Integer> idList = Collections.singletonList(1);
+        TaskInstance instance = new TaskInstance();
+        instance.setId(1);
+
+        Mockito.when(taskInstanceMapper.selectBatchIds(idList)).thenReturn(Collections.singletonList(instance));
+        List<TaskInstance> taskInstanceByIdList = processService.findTaskInstanceByIdList(idList);
+
+        Assert.assertEquals(1, taskInstanceByIdList.size());
+        Assert.assertEquals(instance.getId(), taskInstanceByIdList.get(0).getId());
+    }
+
+    @Test
+    public void testFindCommandPageBySlot() {
+        int pageSize = 1;
+        int pageNumber = 0;
+        int masterCount = 0;
+        int thisMasterSlot = 2;
+        List<Command> commandList = processService.findCommandPageBySlot(pageSize, pageNumber, masterCount, thisMasterSlot);
+        Assert.assertEquals(0, commandList.size());
+    }
+
+    private TaskGroupQueue getTaskGroupQueue() {
+        TaskGroupQueue taskGroupQueue = new TaskGroupQueue();
+        taskGroupQueue.setTaskName("task name");
+        taskGroupQueue.setId(1);
+        taskGroupQueue.setGroupId(1);
+        taskGroupQueue.setTaskId(1);
+        taskGroupQueue.setPriority(1);
+        taskGroupQueue.setStatus(TaskGroupQueueStatus.ACQUIRE_SUCCESS);
+        Date date = new Date(System.currentTimeMillis());
+        taskGroupQueue.setUpdateTime(date);
+        taskGroupQueue.setCreateTime(date);
+        return taskGroupQueue;
+    }
 }
